# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.change import Change

class TestChange(unittest.TestCase):
    """Change unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Change:
        """Test Change
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Change`
        """
        model = Change()
        if include_optional:
            return Change(
                change_type = '',
                drive = google_drive_ti.models.drive.Drive(
                    background_image_file = google_drive_ti.models.drive_background_image_file.Drive_backgroundImageFile(
                        id = '', 
                        width = 1.337, 
                        x_coordinate = 1.337, 
                        y_coordinate = 1.337, ), 
                    background_image_link = '', 
                    capabilities = google_drive_ti.models.drive_capabilities.Drive_capabilities(
                        can_add_children = True, 
                        can_change_copy_requires_writer_permission_restriction = True, 
                        can_change_domain_users_only_restriction = True, 
                        can_change_drive_background = True, 
                        can_change_drive_members_only_restriction = True, 
                        can_change_sharing_folders_requires_organizer_permission_restriction = True, 
                        can_comment = True, 
                        can_copy = True, 
                        can_delete_children = True, 
                        can_delete_drive = True, 
                        can_download = True, 
                        can_edit = True, 
                        can_list_children = True, 
                        can_manage_members = True, 
                        can_read_revisions = True, 
                        can_rename = True, 
                        can_rename_drive = True, 
                        can_reset_drive_restrictions = True, 
                        can_share = True, 
                        can_trash_children = True, ), 
                    color_rgb = '', 
                    created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    hidden = True, 
                    id = '', 
                    kind = 'drive#drive', 
                    name = '', 
                    org_unit_id = '', 
                    restrictions = google_drive_ti.models.drive_restrictions.Drive_restrictions(
                        admin_managed_restrictions = True, 
                        copy_requires_writer_permission = True, 
                        domain_users_only = True, 
                        drive_members_only = True, 
                        sharing_folders_requires_organizer_permission = True, ), 
                    theme_id = '', ),
                drive_id = '',
                file = google_drive_ti.models.file.File(
                    app_properties = google_drive_ti.models.app_properties.appProperties(), 
                    capabilities = google_drive_ti.models.file_capabilities.File_capabilities(
                        can_accept_ownership = True, 
                        can_add_children = True, 
                        can_add_folder_from_another_drive = True, 
                        can_add_my_drive_parent = True, 
                        can_change_copy_requires_writer_permission = True, 
                        can_change_security_update_enabled = True, 
                        can_change_viewers_can_copy_content = True, 
                        can_comment = True, 
                        can_copy = True, 
                        can_delete = True, 
                        can_delete_children = True, 
                        can_download = True, 
                        can_edit = True, 
                        can_list_children = True, 
                        can_modify_content = True, 
                        can_modify_content_restriction = True, 
                        can_modify_editor_content_restriction = True, 
                        can_modify_labels = True, 
                        can_modify_owner_content_restriction = True, 
                        can_move_children_out_of_drive = True, 
                        can_move_children_out_of_team_drive = True, 
                        can_move_children_within_drive = True, 
                        can_move_children_within_team_drive = True, 
                        can_move_item_into_team_drive = True, 
                        can_move_item_out_of_drive = True, 
                        can_move_item_out_of_team_drive = True, 
                        can_move_item_within_drive = True, 
                        can_move_item_within_team_drive = True, 
                        can_move_team_drive_item = True, 
                        can_read_drive = True, 
                        can_read_labels = True, 
                        can_read_revisions = True, 
                        can_read_team_drive = True, 
                        can_remove_children = True, 
                        can_remove_content_restriction = True, 
                        can_remove_my_drive_parent = True, 
                        can_rename = True, 
                        can_share = True, 
                        can_trash = True, 
                        can_trash_children = True, 
                        can_untrash = True, ), 
                    content_hints = google_drive_ti.models.file_content_hints.File_contentHints(
                        indexable_text = '', 
                        thumbnail = google_drive_ti.models.file_content_hints_thumbnail.File_contentHints_thumbnail(
                            image = 'YQ==', 
                            mime_type = '', ), ), 
                    content_restrictions = [
                        google_drive_ti.models.content_restriction.ContentRestriction(
                            owner_restricted = True, 
                            read_only = True, 
                            reason = '', 
                            restricting_user = google_drive_ti.models.user.User(
                                display_name = '', 
                                email_address = '', 
                                kind = 'drive#user', 
                                me = True, 
                                permission_id = '', 
                                photo_link = '', ), 
                            restriction_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            system_restricted = True, 
                            type = '', )
                        ], 
                    copy_requires_writer_permission = True, 
                    created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    drive_id = '', 
                    explicitly_trashed = True, 
                    export_links = google_drive_ti.models.export_links.exportLinks(), 
                    file_extension = '', 
                    folder_color_rgb = '', 
                    full_file_extension = '', 
                    has_augmented_permissions = True, 
                    has_thumbnail = True, 
                    head_revision_id = '', 
                    icon_link = '', 
                    id = '', 
                    image_media_metadata = google_drive_ti.models.file_image_media_metadata.File_imageMediaMetadata(
                        aperture = 1.337, 
                        camera_make = '', 
                        camera_model = '', 
                        color_space = '', 
                        exposure_bias = 1.337, 
                        exposure_mode = '', 
                        exposure_time = 1.337, 
                        flash_used = True, 
                        focal_length = 1.337, 
                        height = 56, 
                        iso_speed = 56, 
                        lens = '', 
                        location = google_drive_ti.models.file_image_media_metadata_location.File_imageMediaMetadata_location(
                            altitude = 1.337, 
                            latitude = 1.337, 
                            longitude = 1.337, ), 
                        max_aperture_value = 1.337, 
                        metering_mode = '', 
                        rotation = 56, 
                        sensor = '', 
                        subject_distance = 56, 
                        time = '', 
                        white_balance = '', 
                        width = 56, ), 
                    is_app_authorized = True, 
                    kind = 'drive#file', 
                    label_info = google_drive_ti.models.file_label_info.File_labelInfo(
                        labels = [
                            google_drive_ti.models.label.Label(
                                fields = google_drive_ti.models.fields.fields(), 
                                id = '', 
                                kind = '', 
                                revision_id = '', )
                            ], ), 
                    last_modifying_user = google_drive_ti.models.user.User(
                        display_name = '', 
                        email_address = '', 
                        kind = 'drive#user', 
                        me = True, 
                        permission_id = '', 
                        photo_link = '', ), 
                    link_share_metadata = google_drive_ti.models.file_link_share_metadata.File_linkShareMetadata(
                        security_update_eligible = True, 
                        security_update_enabled = True, ), 
                    md5_checksum = '', 
                    mime_type = '', 
                    modified_by_me = True, 
                    modified_by_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    name = '', 
                    original_filename = '', 
                    owned_by_me = True, 
                    owners = [
                        
                        ], 
                    parents = [
                        ''
                        ], 
                    permission_ids = [
                        ''
                        ], 
                    permissions = [
                        google_drive_ti.models.permission.Permission(
                            allow_file_discovery = True, 
                            deleted = True, 
                            display_name = '', 
                            domain = '', 
                            email_address = '', 
                            expiration_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = '', 
                            kind = 'drive#permission', 
                            pending_owner = True, 
                            permission_details = [
                                google_drive_ti.models.permission_permission_details_inner.Permission_permissionDetails_inner(
                                    inherited = True, 
                                    inherited_from = '', 
                                    permission_type = '', 
                                    role = '', )
                                ], 
                            photo_link = '', 
                            role = '', 
                            team_drive_permission_details = [
                                google_drive_ti.models.permission_team_drive_permission_details_inner.Permission_teamDrivePermissionDetails_inner(
                                    inherited = True, 
                                    inherited_from = '', 
                                    role = '', 
                                    team_drive_permission_type = '', )
                                ], 
                            type = '', 
                            view = '', )
                        ], 
                    properties = google_drive_ti.models.properties.properties(), 
                    quota_bytes_used = '', 
                    resource_key = '', 
                    sha1_checksum = '', 
                    sha256_checksum = '', 
                    shared = True, 
                    shared_with_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    sharing_user = , 
                    shortcut_details = google_drive_ti.models.file_shortcut_details.File_shortcutDetails(
                        target_id = '', 
                        target_mime_type = '', 
                        target_resource_key = '', ), 
                    size = '', 
                    spaces = [
                        ''
                        ], 
                    starred = True, 
                    team_drive_id = '', 
                    thumbnail_link = '', 
                    thumbnail_version = '', 
                    trashed = True, 
                    trashed_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    trashing_user = , 
                    version = '', 
                    video_media_metadata = google_drive_ti.models.file_video_media_metadata.File_videoMediaMetadata(
                        duration_millis = '', 
                        height = 56, 
                        width = 56, ), 
                    viewed_by_me = True, 
                    viewed_by_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    viewers_can_copy_content = True, 
                    web_content_link = '', 
                    web_view_link = '', 
                    writers_can_share = True, ),
                file_id = '',
                kind = 'drive#change',
                removed = True,
                team_drive = google_drive_ti.models.team_drive.TeamDrive(
                    background_image_file = google_drive_ti.models.team_drive_background_image_file.TeamDrive_backgroundImageFile(
                        id = '', 
                        width = 1.337, 
                        x_coordinate = 1.337, 
                        y_coordinate = 1.337, ), 
                    background_image_link = '', 
                    capabilities = google_drive_ti.models.team_drive_capabilities.TeamDrive_capabilities(
                        can_add_children = True, 
                        can_change_copy_requires_writer_permission_restriction = True, 
                        can_change_domain_users_only_restriction = True, 
                        can_change_sharing_folders_requires_organizer_permission_restriction = True, 
                        can_change_team_drive_background = True, 
                        can_change_team_members_only_restriction = True, 
                        can_comment = True, 
                        can_copy = True, 
                        can_delete_children = True, 
                        can_delete_team_drive = True, 
                        can_download = True, 
                        can_edit = True, 
                        can_list_children = True, 
                        can_manage_members = True, 
                        can_read_revisions = True, 
                        can_remove_children = True, 
                        can_rename = True, 
                        can_rename_team_drive = True, 
                        can_reset_team_drive_restrictions = True, 
                        can_share = True, 
                        can_trash_children = True, ), 
                    color_rgb = '', 
                    created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    kind = 'drive#teamDrive', 
                    name = '', 
                    org_unit_id = '', 
                    restrictions = google_drive_ti.models.team_drive_restrictions.TeamDrive_restrictions(
                        admin_managed_restrictions = True, 
                        copy_requires_writer_permission = True, 
                        domain_users_only = True, 
                        sharing_folders_requires_organizer_permission = True, 
                        team_members_only = True, ), 
                    theme_id = '', ),
                team_drive_id = '',
                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                type = ''
            )
        else:
            return Change(
        )
        """

    def testChange(self):
        """Test Change"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class DriveRestrictions(BaseModel):
    """
    A set of restrictions that apply to this shared drive or items inside this shared drive. Note that restrictions can't be set when creating a shared drive. To add a restriction, first create a shared drive and then use `drives.update` to add restrictions.
    """ # noqa: E501
    admin_managed_restrictions: Optional[StrictBool] = Field(default=None, description="Whether administrative privileges on this shared drive are required to modify restrictions.", alias="adminManagedRestrictions")
    copy_requires_writer_permission: Optional[StrictBool] = Field(default=None, description="Whether the options to copy, print, or download files inside this shared drive, should be disabled for readers and commenters. When this restriction is set to `true`, it will override the similarly named field to `true` for any file inside this shared drive.", alias="copyRequiresWriterPermission")
    domain_users_only: Optional[StrictBool] = Field(default=None, description="Whether access to this shared drive and items inside this shared drive is restricted to users of the domain to which this shared drive belongs. This restriction may be overridden by other sharing policies controlled outside of this shared drive.", alias="domainUsersOnly")
    drive_members_only: Optional[StrictBool] = Field(default=None, description="Whether access to items inside this shared drive is restricted to its members.", alias="driveMembersOnly")
    sharing_folders_requires_organizer_permission: Optional[StrictBool] = Field(default=None, description="If true, only users with the organizer role can share folders. If false, users with either the organizer role or the file organizer role can share folders.", alias="sharingFoldersRequiresOrganizerPermission")
    __properties: ClassVar[List[str]] = ["adminManagedRestrictions", "copyRequiresWriterPermission", "domainUsersOnly", "driveMembersOnly", "sharingFoldersRequiresOrganizerPermission"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DriveRestrictions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DriveRestrictions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "adminManagedRestrictions": obj.get("adminManagedRestrictions"),
            "copyRequiresWriterPermission": obj.get("copyRequiresWriterPermission"),
            "domainUsersOnly": obj.get("domainUsersOnly"),
            "driveMembersOnly": obj.get("driveMembersOnly"),
            "sharingFoldersRequiresOrganizerPermission": obj.get("sharingFoldersRequiresOrganizerPermission")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Revision(BaseModel):
    """
    The metadata for a revision to a file. Some resource methods (such as `revisions.update`) require a `revisionId`. Use the `revisions.list` method to retrieve the ID for a revision.
    """ # noqa: E501
    export_links: Optional[Dict[str, Any]] = Field(default=None, description="Output only. Links for exporting Docs Editors files to specific formats.", alias="exportLinks")
    id: Optional[StrictStr] = Field(default=None, description="Output only. The ID of the revision.")
    keep_forever: Optional[StrictBool] = Field(default=None, description="Whether to keep this revision forever, even if it is no longer the head revision. If not set, the revision will be automatically purged 30 days after newer content is uploaded. This can be set on a maximum of 200 revisions for a file. This field is only applicable to files with binary content in Drive.", alias="keepForever")
    kind: Optional[StrictStr] = Field(default='drive#revision', description="Output only. Identifies what kind of resource this is. Value: the fixed string `\"drive#revision\"`.")
    last_modifying_user: Optional[User] = Field(default=None, alias="lastModifyingUser")
    md5_checksum: Optional[StrictStr] = Field(default=None, description="Output only. The MD5 checksum of the revision's content. This is only applicable to files with binary content in Drive.", alias="md5Checksum")
    mime_type: Optional[StrictStr] = Field(default=None, description="Output only. The MIME type of the revision.", alias="mimeType")
    modified_time: Optional[datetime] = Field(default=None, description="The last time the revision was modified (RFC 3339 date-time).", alias="modifiedTime")
    original_filename: Optional[StrictStr] = Field(default=None, description="Output only. The original filename used to create this revision. This is only applicable to files with binary content in Drive.", alias="originalFilename")
    publish_auto: Optional[StrictBool] = Field(default=None, description="Whether subsequent revisions will be automatically republished. This is only applicable to Docs Editors files.", alias="publishAuto")
    published: Optional[StrictBool] = Field(default=None, description="Whether this revision is published. This is only applicable to Docs Editors files.")
    published_link: Optional[StrictStr] = Field(default=None, description="Output only. A link to the published revision. This is only populated for Docs Editors files.", alias="publishedLink")
    published_outside_domain: Optional[StrictBool] = Field(default=None, description="Whether this revision is published outside the domain. This is only applicable to Docs Editors files.", alias="publishedOutsideDomain")
    size: Optional[StrictStr] = Field(default=None, description="Output only. The size of the revision's content in bytes. This is only applicable to files with binary content in Drive.")
    __properties: ClassVar[List[str]] = ["exportLinks", "id", "keepForever", "kind", "lastModifyingUser", "md5Checksum", "mimeType", "modifiedTime", "originalFilename", "publishAuto", "published", "publishedLink", "publishedOutsideDomain", "size"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Revision from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of last_modifying_user
        if self.last_modifying_user:
            _dict['lastModifyingUser'] = self.last_modifying_user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Revision from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "exportLinks": obj.get("exportLinks"),
            "id": obj.get("id"),
            "keepForever": obj.get("keepForever"),
            "kind": obj.get("kind") if obj.get("kind") is not None else 'drive#revision',
            "lastModifyingUser": User.from_dict(obj["lastModifyingUser"]) if obj.get("lastModifyingUser") is not None else None,
            "md5Checksum": obj.get("md5Checksum"),
            "mimeType": obj.get("mimeType"),
            "modifiedTime": obj.get("modifiedTime"),
            "originalFilename": obj.get("originalFilename"),
            "publishAuto": obj.get("publishAuto"),
            "published": obj.get("published"),
            "publishedLink": obj.get("publishedLink"),
            "publishedOutsideDomain": obj.get("publishedOutsideDomain"),
            "size": obj.get("size")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Reply(BaseModel):
    """
    A reply to a comment on a file. Some resource methods (such as `replies.update`) require a `replyId`. Use the `replies.list` method to retrieve the ID for a reply.
    """ # noqa: E501
    action: Optional[StrictStr] = Field(default=None, description="The action the reply performed to the parent comment. Valid values are: * `resolve` * `reopen`")
    author: Optional[User] = None
    content: Optional[StrictStr] = Field(default=None, description="The plain text content of the reply. This field is used for setting the content, while `htmlContent` should be displayed. This is required on creates if no `action` is specified.")
    created_time: Optional[datetime] = Field(default=None, description="The time at which the reply was created (RFC 3339 date-time).", alias="createdTime")
    deleted: Optional[StrictBool] = Field(default=None, description="Output only. Whether the reply has been deleted. A deleted reply has no content.")
    html_content: Optional[StrictStr] = Field(default=None, description="Output only. The content of the reply with HTML formatting.", alias="htmlContent")
    id: Optional[StrictStr] = Field(default=None, description="Output only. The ID of the reply.")
    kind: Optional[StrictStr] = Field(default='drive#reply', description="Output only. Identifies what kind of resource this is. Value: the fixed string `\"drive#reply\"`.")
    modified_time: Optional[datetime] = Field(default=None, description="The last time the reply was modified (RFC 3339 date-time).", alias="modifiedTime")
    __properties: ClassVar[List[str]] = ["action", "author", "content", "createdTime", "deleted", "htmlContent", "id", "kind", "modifiedTime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Reply from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of author
        if self.author:
            _dict['author'] = self.author.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Reply from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "action": obj.get("action"),
            "author": User.from_dict(obj["author"]) if obj.get("author") is not None else None,
            "content": obj.get("content"),
            "createdTime": obj.get("createdTime"),
            "deleted": obj.get("deleted"),
            "htmlContent": obj.get("htmlContent"),
            "id": obj.get("id"),
            "kind": obj.get("kind") if obj.get("kind") is not None else 'drive#reply',
            "modifiedTime": obj.get("modifiedTime")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.3"

# import apis into sdk package
from google_drive_ti.api.about_api import AboutApi
from google_drive_ti.api.accessproposals_api import AccessproposalsApi
from google_drive_ti.api.apps_api import AppsApi
from google_drive_ti.api.changes_api import ChangesApi
from google_drive_ti.api.channels_api import ChannelsApi
from google_drive_ti.api.comments_api import CommentsApi
from google_drive_ti.api.drives_api import DrivesApi
from google_drive_ti.api.files_api import FilesApi
from google_drive_ti.api.operation_api import OperationApi
from google_drive_ti.api.operations_api import OperationsApi
from google_drive_ti.api.permissions_api import PermissionsApi
from google_drive_ti.api.replies_api import RepliesApi
from google_drive_ti.api.revisions_api import RevisionsApi
from google_drive_ti.api.teamdrives_api import TeamdrivesApi

# import ApiClient
from google_drive_ti.api_response import ApiResponse
from google_drive_ti.api_client import ApiClient
from google_drive_ti.configuration import Configuration
from google_drive_ti.exceptions import OpenApiException
from google_drive_ti.exceptions import ApiTypeError
from google_drive_ti.exceptions import ApiValueError
from google_drive_ti.exceptions import ApiKeyError
from google_drive_ti.exceptions import ApiAttributeError
from google_drive_ti.exceptions import ApiException

# import models into sdk package
from google_drive_ti.models.about import About
from google_drive_ti.models.about_drive_themes_inner import AboutDriveThemesInner
from google_drive_ti.models.about_storage_quota import AboutStorageQuota
from google_drive_ti.models.about_team_drive_themes_inner import AboutTeamDriveThemesInner
from google_drive_ti.models.access_proposal import AccessProposal
from google_drive_ti.models.access_proposal_role_and_view import AccessProposalRoleAndView
from google_drive_ti.models.app import App
from google_drive_ti.models.app_icons import AppIcons
from google_drive_ti.models.app_list import AppList
from google_drive_ti.models.change import Change
from google_drive_ti.models.change_list import ChangeList
from google_drive_ti.models.channel import Channel
from google_drive_ti.models.comment import Comment
from google_drive_ti.models.comment_list import CommentList
from google_drive_ti.models.comment_quoted_file_content import CommentQuotedFileContent
from google_drive_ti.models.content_restriction import ContentRestriction
from google_drive_ti.models.drive import Drive
from google_drive_ti.models.drive_background_image_file import DriveBackgroundImageFile
from google_drive_ti.models.drive_capabilities import DriveCapabilities
from google_drive_ti.models.drive_list import DriveList
from google_drive_ti.models.drive_restrictions import DriveRestrictions
from google_drive_ti.models.file import File
from google_drive_ti.models.file_capabilities import FileCapabilities
from google_drive_ti.models.file_content_hints import FileContentHints
from google_drive_ti.models.file_content_hints_thumbnail import FileContentHintsThumbnail
from google_drive_ti.models.file_image_media_metadata import FileImageMediaMetadata
from google_drive_ti.models.file_image_media_metadata_location import FileImageMediaMetadataLocation
from google_drive_ti.models.file_label_info import FileLabelInfo
from google_drive_ti.models.file_link_share_metadata import FileLinkShareMetadata
from google_drive_ti.models.file_list import FileList
from google_drive_ti.models.file_shortcut_details import FileShortcutDetails
from google_drive_ti.models.file_video_media_metadata import FileVideoMediaMetadata
from google_drive_ti.models.generated_ids import GeneratedIds
from google_drive_ti.models.label import Label
from google_drive_ti.models.label_field import LabelField
from google_drive_ti.models.label_field_modification import LabelFieldModification
from google_drive_ti.models.label_list import LabelList
from google_drive_ti.models.label_modification import LabelModification
from google_drive_ti.models.list_access_proposals_response import ListAccessProposalsResponse
from google_drive_ti.models.list_operations_response import ListOperationsResponse
from google_drive_ti.models.modify_labels_request import ModifyLabelsRequest
from google_drive_ti.models.modify_labels_response import ModifyLabelsResponse
from google_drive_ti.models.operation import Operation
from google_drive_ti.models.permission import Permission
from google_drive_ti.models.permission_list import PermissionList
from google_drive_ti.models.permission_permission_details_inner import PermissionPermissionDetailsInner
from google_drive_ti.models.permission_team_drive_permission_details_inner import PermissionTeamDrivePermissionDetailsInner
from google_drive_ti.models.reply import Reply
from google_drive_ti.models.reply_list import ReplyList
from google_drive_ti.models.resolve_access_proposal_request import ResolveAccessProposalRequest
from google_drive_ti.models.revision import Revision
from google_drive_ti.models.revision_list import RevisionList
from google_drive_ti.models.start_page_token import StartPageToken
from google_drive_ti.models.status import Status
from google_drive_ti.models.team_drive import TeamDrive
from google_drive_ti.models.team_drive_background_image_file import TeamDriveBackgroundImageFile
from google_drive_ti.models.team_drive_capabilities import TeamDriveCapabilities
from google_drive_ti.models.team_drive_list import TeamDriveList
from google_drive_ti.models.team_drive_restrictions import TeamDriveRestrictions
from google_drive_ti.models.user import User



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class ContentRestriction(BaseModel):
    """
    A restriction for accessing the content of the file.
    """ # noqa: E501
    owner_restricted: Optional[StrictBool] = Field(default=None, description="Whether the content restriction can only be modified or removed by a user who owns the file. For files in shared drives, any user with `organizer` capabilities can modify or remove this content restriction.", alias="ownerRestricted")
    read_only: Optional[StrictBool] = Field(default=None, description="Whether the content of the file is read-only. If a file is read-only, a new revision of the file may not be added, comments may not be added or modified, and the title of the file may not be modified.", alias="readOnly")
    reason: Optional[StrictStr] = Field(default=None, description="Reason for why the content of the file is restricted. This is only mutable on requests that also set `readOnly=true`.")
    restricting_user: Optional[User] = Field(default=None, alias="restrictingUser")
    restriction_time: Optional[datetime] = Field(default=None, description="The time at which the content restriction was set (formatted RFC 3339 timestamp). Only populated if readOnly is true.", alias="restrictionTime")
    system_restricted: Optional[StrictBool] = Field(default=None, description="Output only. Whether the content restriction was applied by the system, for example due to an esignature. Users cannot modify or remove system restricted content restrictions.", alias="systemRestricted")
    type: Optional[StrictStr] = Field(default=None, description="Output only. The type of the content restriction. Currently the only possible value is `globalContentRestriction`.")
    __properties: ClassVar[List[str]] = ["ownerRestricted", "readOnly", "reason", "restrictingUser", "restrictionTime", "systemRestricted", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ContentRestriction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of restricting_user
        if self.restricting_user:
            _dict['restrictingUser'] = self.restricting_user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ContentRestriction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ownerRestricted": obj.get("ownerRestricted"),
            "readOnly": obj.get("readOnly"),
            "reason": obj.get("reason"),
            "restrictingUser": User.from_dict(obj["restrictingUser"]) if obj.get("restrictingUser") is not None else None,
            "restrictionTime": obj.get("restrictionTime"),
            "systemRestricted": obj.get("systemRestricted"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.file import File

class TestFile(unittest.TestCase):
    """File unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> File:
        """Test File
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `File`
        """
        model = File()
        if include_optional:
            return File(
                app_properties = google_drive_ti.models.app_properties.appProperties(),
                capabilities = google_drive_ti.models.file_capabilities.File_capabilities(
                    can_accept_ownership = True, 
                    can_add_children = True, 
                    can_add_folder_from_another_drive = True, 
                    can_add_my_drive_parent = True, 
                    can_change_copy_requires_writer_permission = True, 
                    can_change_security_update_enabled = True, 
                    can_change_viewers_can_copy_content = True, 
                    can_comment = True, 
                    can_copy = True, 
                    can_delete = True, 
                    can_delete_children = True, 
                    can_download = True, 
                    can_edit = True, 
                    can_list_children = True, 
                    can_modify_content = True, 
                    can_modify_content_restriction = True, 
                    can_modify_editor_content_restriction = True, 
                    can_modify_labels = True, 
                    can_modify_owner_content_restriction = True, 
                    can_move_children_out_of_drive = True, 
                    can_move_children_out_of_team_drive = True, 
                    can_move_children_within_drive = True, 
                    can_move_children_within_team_drive = True, 
                    can_move_item_into_team_drive = True, 
                    can_move_item_out_of_drive = True, 
                    can_move_item_out_of_team_drive = True, 
                    can_move_item_within_drive = True, 
                    can_move_item_within_team_drive = True, 
                    can_move_team_drive_item = True, 
                    can_read_drive = True, 
                    can_read_labels = True, 
                    can_read_revisions = True, 
                    can_read_team_drive = True, 
                    can_remove_children = True, 
                    can_remove_content_restriction = True, 
                    can_remove_my_drive_parent = True, 
                    can_rename = True, 
                    can_share = True, 
                    can_trash = True, 
                    can_trash_children = True, 
                    can_untrash = True, ),
                content_hints = google_drive_ti.models.file_content_hints.File_contentHints(
                    indexable_text = '', 
                    thumbnail = google_drive_ti.models.file_content_hints_thumbnail.File_contentHints_thumbnail(
                        image = 'YQ==', 
                        mime_type = '', ), ),
                content_restrictions = [
                    google_drive_ti.models.content_restriction.ContentRestriction(
                        owner_restricted = True, 
                        read_only = True, 
                        reason = '', 
                        restricting_user = google_drive_ti.models.user.User(
                            display_name = '', 
                            email_address = '', 
                            kind = 'drive#user', 
                            me = True, 
                            permission_id = '', 
                            photo_link = '', ), 
                        restriction_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        system_restricted = True, 
                        type = '', )
                    ],
                copy_requires_writer_permission = True,
                created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                description = '',
                drive_id = '',
                explicitly_trashed = True,
                export_links = google_drive_ti.models.export_links.exportLinks(),
                file_extension = '',
                folder_color_rgb = '',
                full_file_extension = '',
                has_augmented_permissions = True,
                has_thumbnail = True,
                head_revision_id = '',
                icon_link = '',
                id = '',
                image_media_metadata = google_drive_ti.models.file_image_media_metadata.File_imageMediaMetadata(
                    aperture = 1.337, 
                    camera_make = '', 
                    camera_model = '', 
                    color_space = '', 
                    exposure_bias = 1.337, 
                    exposure_mode = '', 
                    exposure_time = 1.337, 
                    flash_used = True, 
                    focal_length = 1.337, 
                    height = 56, 
                    iso_speed = 56, 
                    lens = '', 
                    location = google_drive_ti.models.file_image_media_metadata_location.File_imageMediaMetadata_location(
                        altitude = 1.337, 
                        latitude = 1.337, 
                        longitude = 1.337, ), 
                    max_aperture_value = 1.337, 
                    metering_mode = '', 
                    rotation = 56, 
                    sensor = '', 
                    subject_distance = 56, 
                    time = '', 
                    white_balance = '', 
                    width = 56, ),
                is_app_authorized = True,
                kind = 'drive#file',
                label_info = google_drive_ti.models.file_label_info.File_labelInfo(
                    labels = [
                        google_drive_ti.models.label.Label(
                            fields = google_drive_ti.models.fields.fields(), 
                            id = '', 
                            kind = '', 
                            revision_id = '', )
                        ], ),
                last_modifying_user = google_drive_ti.models.user.User(
                    display_name = '', 
                    email_address = '', 
                    kind = 'drive#user', 
                    me = True, 
                    permission_id = '', 
                    photo_link = '', ),
                link_share_metadata = google_drive_ti.models.file_link_share_metadata.File_linkShareMetadata(
                    security_update_eligible = True, 
                    security_update_enabled = True, ),
                md5_checksum = '',
                mime_type = '',
                modified_by_me = True,
                modified_by_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                modified_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                name = '',
                original_filename = '',
                owned_by_me = True,
                owners = [
                    google_drive_ti.models.user.User(
                        display_name = '', 
                        email_address = '', 
                        kind = 'drive#user', 
                        me = True, 
                        permission_id = '', 
                        photo_link = '', )
                    ],
                parents = [
                    ''
                    ],
                permission_ids = [
                    ''
                    ],
                permissions = [
                    google_drive_ti.models.permission.Permission(
                        allow_file_discovery = True, 
                        deleted = True, 
                        display_name = '', 
                        domain = '', 
                        email_address = '', 
                        expiration_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        kind = 'drive#permission', 
                        pending_owner = True, 
                        permission_details = [
                            google_drive_ti.models.permission_permission_details_inner.Permission_permissionDetails_inner(
                                inherited = True, 
                                inherited_from = '', 
                                permission_type = '', 
                                role = '', )
                            ], 
                        photo_link = '', 
                        role = '', 
                        team_drive_permission_details = [
                            google_drive_ti.models.permission_team_drive_permission_details_inner.Permission_teamDrivePermissionDetails_inner(
                                inherited = True, 
                                inherited_from = '', 
                                role = '', 
                                team_drive_permission_type = '', )
                            ], 
                        type = '', 
                        view = '', )
                    ],
                properties = google_drive_ti.models.properties.properties(),
                quota_bytes_used = '',
                resource_key = '',
                sha1_checksum = '',
                sha256_checksum = '',
                shared = True,
                shared_with_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                sharing_user = google_drive_ti.models.user.User(
                    display_name = '', 
                    email_address = '', 
                    kind = 'drive#user', 
                    me = True, 
                    permission_id = '', 
                    photo_link = '', ),
                shortcut_details = google_drive_ti.models.file_shortcut_details.File_shortcutDetails(
                    target_id = '', 
                    target_mime_type = '', 
                    target_resource_key = '', ),
                size = '',
                spaces = [
                    ''
                    ],
                starred = True,
                team_drive_id = '',
                thumbnail_link = '',
                thumbnail_version = '',
                trashed = True,
                trashed_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                trashing_user = google_drive_ti.models.user.User(
                    display_name = '', 
                    email_address = '', 
                    kind = 'drive#user', 
                    me = True, 
                    permission_id = '', 
                    photo_link = '', ),
                version = '',
                video_media_metadata = google_drive_ti.models.file_video_media_metadata.File_videoMediaMetadata(
                    duration_millis = '', 
                    height = 56, 
                    width = 56, ),
                viewed_by_me = True,
                viewed_by_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                viewers_can_copy_content = True,
                web_content_link = '',
                web_view_link = '',
                writers_can_share = True
            )
        else:
            return File(
        )
        """

    def testFile(self):
        """Test File"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.label_field import LabelField

class TestLabelField(unittest.TestCase):
    """LabelField unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LabelField:
        """Test LabelField
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LabelField`
        """
        model = LabelField()
        if include_optional:
            return LabelField(
                date_string = [
                    datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date()
                    ],
                id = '',
                integer = [
                    ''
                    ],
                kind = '',
                selection = [
                    ''
                    ],
                text = [
                    ''
                    ],
                user = [
                    google_drive_ti.models.user.User(
                        display_name = '', 
                        email_address = '', 
                        kind = 'drive#user', 
                        me = True, 
                        permission_id = '', 
                        photo_link = '', )
                    ],
                value_type = ''
            )
        else:
            return LabelField(
        )
        """

    def testLabelField(self):
        """Test LabelField"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class DriveCapabilities(BaseModel):
    """
    Output only. Capabilities the current user has on this shared drive.
    """ # noqa: E501
    can_add_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can add children to folders in this shared drive.", alias="canAddChildren")
    can_change_copy_requires_writer_permission_restriction: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can change the `copyRequiresWriterPermission` restriction of this shared drive.", alias="canChangeCopyRequiresWriterPermissionRestriction")
    can_change_domain_users_only_restriction: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can change the `domainUsersOnly` restriction of this shared drive.", alias="canChangeDomainUsersOnlyRestriction")
    can_change_drive_background: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can change the background of this shared drive.", alias="canChangeDriveBackground")
    can_change_drive_members_only_restriction: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can change the `driveMembersOnly` restriction of this shared drive.", alias="canChangeDriveMembersOnlyRestriction")
    can_change_sharing_folders_requires_organizer_permission_restriction: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can change the `sharingFoldersRequiresOrganizerPermission` restriction of this shared drive.", alias="canChangeSharingFoldersRequiresOrganizerPermissionRestriction")
    can_comment: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can comment on files in this shared drive.", alias="canComment")
    can_copy: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can copy files in this shared drive.", alias="canCopy")
    can_delete_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can delete children from folders in this shared drive.", alias="canDeleteChildren")
    can_delete_drive: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can delete this shared drive. Attempting to delete the shared drive may still fail if there are untrashed items inside the shared drive.", alias="canDeleteDrive")
    can_download: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can download files in this shared drive.", alias="canDownload")
    can_edit: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can edit files in this shared drive", alias="canEdit")
    can_list_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can list the children of folders in this shared drive.", alias="canListChildren")
    can_manage_members: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can add members to this shared drive or remove them or change their role.", alias="canManageMembers")
    can_read_revisions: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can read the revisions resource of files in this shared drive.", alias="canReadRevisions")
    can_rename: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can rename files or folders in this shared drive.", alias="canRename")
    can_rename_drive: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can rename this shared drive.", alias="canRenameDrive")
    can_reset_drive_restrictions: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can reset the shared drive restrictions to defaults.", alias="canResetDriveRestrictions")
    can_share: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can share files or folders in this shared drive.", alias="canShare")
    can_trash_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can trash children from folders in this shared drive.", alias="canTrashChildren")
    __properties: ClassVar[List[str]] = ["canAddChildren", "canChangeCopyRequiresWriterPermissionRestriction", "canChangeDomainUsersOnlyRestriction", "canChangeDriveBackground", "canChangeDriveMembersOnlyRestriction", "canChangeSharingFoldersRequiresOrganizerPermissionRestriction", "canComment", "canCopy", "canDeleteChildren", "canDeleteDrive", "canDownload", "canEdit", "canListChildren", "canManageMembers", "canReadRevisions", "canRename", "canRenameDrive", "canResetDriveRestrictions", "canShare", "canTrashChildren"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DriveCapabilities from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DriveCapabilities from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "canAddChildren": obj.get("canAddChildren"),
            "canChangeCopyRequiresWriterPermissionRestriction": obj.get("canChangeCopyRequiresWriterPermissionRestriction"),
            "canChangeDomainUsersOnlyRestriction": obj.get("canChangeDomainUsersOnlyRestriction"),
            "canChangeDriveBackground": obj.get("canChangeDriveBackground"),
            "canChangeDriveMembersOnlyRestriction": obj.get("canChangeDriveMembersOnlyRestriction"),
            "canChangeSharingFoldersRequiresOrganizerPermissionRestriction": obj.get("canChangeSharingFoldersRequiresOrganizerPermissionRestriction"),
            "canComment": obj.get("canComment"),
            "canCopy": obj.get("canCopy"),
            "canDeleteChildren": obj.get("canDeleteChildren"),
            "canDeleteDrive": obj.get("canDeleteDrive"),
            "canDownload": obj.get("canDownload"),
            "canEdit": obj.get("canEdit"),
            "canListChildren": obj.get("canListChildren"),
            "canManageMembers": obj.get("canManageMembers"),
            "canReadRevisions": obj.get("canReadRevisions"),
            "canRename": obj.get("canRename"),
            "canRenameDrive": obj.get("canRenameDrive"),
            "canResetDriveRestrictions": obj.get("canResetDriveRestrictions"),
            "canShare": obj.get("canShare"),
            "canTrashChildren": obj.get("canTrashChildren")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AboutStorageQuota(BaseModel):
    """
    The user's storage quota limits and usage. For users that are part of an organization with pooled storage, information about the limit and usage across all services is for the organization, rather than the individual user. All fields are measured in bytes.
    """ # noqa: E501
    limit: Optional[StrictStr] = Field(default=None, description="The usage limit, if applicable. This will not be present if the user has unlimited storage. For users that are part of an organization with pooled storage, this is the limit for the organization, rather than the individual user.")
    usage: Optional[StrictStr] = Field(default=None, description="The total usage across all services. For users that are part of an organization with pooled storage, this is the usage across all services for the organization, rather than the individual user.")
    usage_in_drive: Optional[StrictStr] = Field(default=None, description="The usage by all files in Google Drive.", alias="usageInDrive")
    usage_in_drive_trash: Optional[StrictStr] = Field(default=None, description="The usage by trashed files in Google Drive.", alias="usageInDriveTrash")
    __properties: ClassVar[List[str]] = ["limit", "usage", "usageInDrive", "usageInDriveTrash"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AboutStorageQuota from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AboutStorageQuota from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "limit": obj.get("limit"),
            "usage": obj.get("usage"),
            "usageInDrive": obj.get("usageInDrive"),
            "usageInDriveTrash": obj.get("usageInDriveTrash")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.drive import Drive
from google_drive_ti.models.file import File
from google_drive_ti.models.team_drive import TeamDrive
from typing import Optional, Set
from typing_extensions import Self

class Change(BaseModel):
    """
    A change to a file or shared drive.
    """ # noqa: E501
    change_type: Optional[StrictStr] = Field(default=None, description="The type of the change. Possible values are `file` and `drive`.", alias="changeType")
    drive: Optional[Drive] = None
    drive_id: Optional[StrictStr] = Field(default=None, description="The ID of the shared drive associated with this change.", alias="driveId")
    file: Optional[File] = None
    file_id: Optional[StrictStr] = Field(default=None, description="The ID of the file which has changed.", alias="fileId")
    kind: Optional[StrictStr] = Field(default='drive#change', description="Identifies what kind of resource this is. Value: the fixed string `\"drive#change\"`.")
    removed: Optional[StrictBool] = Field(default=None, description="Whether the file or shared drive has been removed from this list of changes, for example by deletion or loss of access.")
    team_drive: Optional[TeamDrive] = Field(default=None, alias="teamDrive")
    team_drive_id: Optional[StrictStr] = Field(default=None, description="Deprecated: Use `driveId` instead.", alias="teamDriveId")
    time: Optional[datetime] = Field(default=None, description="The time of this change (RFC 3339 date-time).")
    type: Optional[StrictStr] = Field(default=None, description="Deprecated: Use `changeType` instead.")
    __properties: ClassVar[List[str]] = ["changeType", "drive", "driveId", "file", "fileId", "kind", "removed", "teamDrive", "teamDriveId", "time", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Change from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of drive
        if self.drive:
            _dict['drive'] = self.drive.to_dict()
        # override the default output from pydantic by calling `to_dict()` of file
        if self.file:
            _dict['file'] = self.file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of team_drive
        if self.team_drive:
            _dict['teamDrive'] = self.team_drive.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Change from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "changeType": obj.get("changeType"),
            "drive": Drive.from_dict(obj["drive"]) if obj.get("drive") is not None else None,
            "driveId": obj.get("driveId"),
            "file": File.from_dict(obj["file"]) if obj.get("file") is not None else None,
            "fileId": obj.get("fileId"),
            "kind": obj.get("kind") if obj.get("kind") is not None else 'drive#change',
            "removed": obj.get("removed"),
            "teamDrive": TeamDrive.from_dict(obj["teamDrive"]) if obj.get("teamDrive") is not None else None,
            "teamDriveId": obj.get("teamDriveId"),
            "time": obj.get("time"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.revision import Revision
from typing import Optional, Set
from typing_extensions import Self

class RevisionList(BaseModel):
    """
    A list of revisions of a file.
    """ # noqa: E501
    kind: Optional[StrictStr] = Field(default='drive#revisionList', description="Identifies what kind of resource this is. Value: the fixed string `\"drive#revisionList\"`.")
    next_page_token: Optional[StrictStr] = Field(default=None, description="The page token for the next page of revisions. This will be absent if the end of the revisions list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ.", alias="nextPageToken")
    revisions: Optional[List[Revision]] = Field(default=None, description="The list of revisions. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched.")
    __properties: ClassVar[List[str]] = ["kind", "nextPageToken", "revisions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RevisionList from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in revisions (list)
        _items = []
        if self.revisions:
            for _item_revisions in self.revisions:
                if _item_revisions:
                    _items.append(_item_revisions.to_dict())
            _dict['revisions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RevisionList from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'drive#revisionList',
            "nextPageToken": obj.get("nextPageToken"),
            "revisions": [Revision.from_dict(_item) for _item in obj["revisions"]] if obj.get("revisions") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.label_modification import LabelModification

class TestLabelModification(unittest.TestCase):
    """LabelModification unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LabelModification:
        """Test LabelModification
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LabelModification`
        """
        model = LabelModification()
        if include_optional:
            return LabelModification(
                field_modifications = [
                    google_drive_ti.models.label_field_modification.LabelFieldModification(
                        field_id = '', 
                        kind = '', 
                        set_date_values = [
                            datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date()
                            ], 
                        set_integer_values = [
                            ''
                            ], 
                        set_selection_values = [
                            ''
                            ], 
                        set_text_values = [
                            ''
                            ], 
                        set_user_values = [
                            ''
                            ], 
                        unset_values = True, )
                    ],
                kind = '',
                label_id = '',
                remove_label = True
            )
        else:
            return LabelModification(
        )
        """

    def testLabelModification(self):
        """Test LabelModification"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Status(BaseModel):
    """
    The `Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](https://github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](https://cloud.google.com/apis/design/errors).
    """ # noqa: E501
    code: Optional[StrictInt] = Field(default=None, description="The status code, which should be an enum value of google.rpc.Code.")
    details: Optional[List[Dict[str, Any]]] = Field(default=None, description="A list of messages that carry the error details. There is a common set of message types for APIs to use.")
    message: Optional[StrictStr] = Field(default=None, description="A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client.")
    __properties: ClassVar[List[str]] = ["code", "details", "message"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Status from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Status from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "code": obj.get("code"),
            "details": obj.get("details"),
            "message": obj.get("message")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.about import About

class TestAbout(unittest.TestCase):
    """About unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> About:
        """Test About
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `About`
        """
        model = About()
        if include_optional:
            return About(
                app_installed = True,
                can_create_drives = True,
                can_create_team_drives = True,
                drive_themes = [
                    google_drive_ti.models.about_drive_themes_inner.About_driveThemes_inner(
                        background_image_link = '', 
                        color_rgb = '', 
                        id = '', )
                    ],
                export_formats = None,
                folder_color_palette = [
                    ''
                    ],
                import_formats = None,
                kind = 'drive#about',
                max_import_sizes = None,
                max_upload_size = '',
                storage_quota = google_drive_ti.models.about_storage_quota.About_storageQuota(
                    limit = '', 
                    usage = '', 
                    usage_in_drive = '', 
                    usage_in_drive_trash = '', ),
                team_drive_themes = [
                    google_drive_ti.models.about_team_drive_themes_inner.About_teamDriveThemes_inner(
                        background_image_link = '', 
                        color_rgb = '', 
                        id = '', )
                    ],
                user = google_drive_ti.models.user.User(
                    display_name = '', 
                    email_address = '', 
                    kind = 'drive#user', 
                    me = True, 
                    permission_id = '', 
                    photo_link = '', )
            )
        else:
            return About(
        )
        """

    def testAbout(self):
        """Test About"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.api.teamdrives_api import TeamdrivesApi


class TestTeamdrivesApi(unittest.TestCase):
    """TeamdrivesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TeamdrivesApi()

    def tearDown(self) -> None:
        pass

    def test_drive_teamdrives_create(self) -> None:
        """Test case for drive_teamdrives_create

        """
        pass

    def test_drive_teamdrives_delete(self) -> None:
        """Test case for drive_teamdrives_delete

        """
        pass

    def test_drive_teamdrives_get(self) -> None:
        """Test case for drive_teamdrives_get

        """
        pass

    def test_drive_teamdrives_list(self) -> None:
        """Test case for drive_teamdrives_list

        """
        pass

    def test_drive_teamdrives_update(self) -> None:
        """Test case for drive_teamdrives_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.api.about_api import AboutApi


class TestAboutApi(unittest.TestCase):
    """AboutApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AboutApi()

    def tearDown(self) -> None:
        pass

    def test_drive_about_get(self) -> None:
        """Test case for drive_about_get

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class FileCapabilities(BaseModel):
    """
    Output only. Capabilities the current user has on this file. Each capability corresponds to a fine-grained action that a user may take.
    """ # noqa: E501
    can_accept_ownership: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user is the pending owner of the file. Not populated for shared drive files.", alias="canAcceptOwnership")
    can_add_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can add children to this folder. This is always false when the item is not a folder.", alias="canAddChildren")
    can_add_folder_from_another_drive: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can add a folder from another drive (different shared drive or My Drive) to this folder. This is false when the item is not a folder. Only populated for items in shared drives.", alias="canAddFolderFromAnotherDrive")
    can_add_my_drive_parent: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can add a parent for the item without removing an existing parent in the same request. Not populated for shared drive files.", alias="canAddMyDriveParent")
    can_change_copy_requires_writer_permission: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can change the `copyRequiresWriterPermission` restriction of this file.", alias="canChangeCopyRequiresWriterPermission")
    can_change_security_update_enabled: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can change the securityUpdateEnabled field on link share metadata.", alias="canChangeSecurityUpdateEnabled")
    can_change_viewers_can_copy_content: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only.", alias="canChangeViewersCanCopyContent")
    can_comment: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can comment on this file.", alias="canComment")
    can_copy: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can copy this file. For an item in a shared drive, whether the current user can copy non-folder descendants of this item, or this item itself if it is not a folder.", alias="canCopy")
    can_delete: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can delete this file.", alias="canDelete")
    can_delete_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can delete children of this folder. This is false when the item is not a folder. Only populated for items in shared drives.", alias="canDeleteChildren")
    can_download: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can download this file.", alias="canDownload")
    can_edit: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can edit this file. Other factors may limit the type of changes a user can make to a file. For example, see `canChangeCopyRequiresWriterPermission` or `canModifyContent`.", alias="canEdit")
    can_list_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can list the children of this folder. This is always false when the item is not a folder.", alias="canListChildren")
    can_modify_content: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can modify the content of this file.", alias="canModifyContent")
    can_modify_content_restriction: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only. Use one of `canModifyEditorContentRestriction`, `canModifyOwnerContentRestriction` or `canRemoveContentRestriction`.", alias="canModifyContentRestriction")
    can_modify_editor_content_restriction: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can add or modify content restrictions on the file which are editor restricted.", alias="canModifyEditorContentRestriction")
    can_modify_labels: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can modify the labels on the file.", alias="canModifyLabels")
    can_modify_owner_content_restriction: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can add or modify content restrictions which are owner restricted.", alias="canModifyOwnerContentRestriction")
    can_move_children_out_of_drive: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can move children of this folder outside of the shared drive. This is false when the item is not a folder. Only populated for items in shared drives.", alias="canMoveChildrenOutOfDrive")
    can_move_children_out_of_team_drive: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only. Use `canMoveChildrenOutOfDrive` instead.", alias="canMoveChildrenOutOfTeamDrive")
    can_move_children_within_drive: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can move children of this folder within this drive. This is false when the item is not a folder. Note that a request to move the child may still fail depending on the current user's access to the child and to the destination folder.", alias="canMoveChildrenWithinDrive")
    can_move_children_within_team_drive: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only. Use `canMoveChildrenWithinDrive` instead.", alias="canMoveChildrenWithinTeamDrive")
    can_move_item_into_team_drive: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only. Use `canMoveItemOutOfDrive` instead.", alias="canMoveItemIntoTeamDrive")
    can_move_item_out_of_drive: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can move this item outside of this drive by changing its parent. Note that a request to change the parent of the item may still fail depending on the new parent that is being added.", alias="canMoveItemOutOfDrive")
    can_move_item_out_of_team_drive: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only. Use `canMoveItemOutOfDrive` instead.", alias="canMoveItemOutOfTeamDrive")
    can_move_item_within_drive: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can move this item within this drive. Note that a request to change the parent of the item may still fail depending on the new parent that is being added and the parent that is being removed.", alias="canMoveItemWithinDrive")
    can_move_item_within_team_drive: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only. Use `canMoveItemWithinDrive` instead.", alias="canMoveItemWithinTeamDrive")
    can_move_team_drive_item: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only. Use `canMoveItemWithinDrive` or `canMoveItemOutOfDrive` instead.", alias="canMoveTeamDriveItem")
    can_read_drive: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can read the shared drive to which this file belongs. Only populated for items in shared drives.", alias="canReadDrive")
    can_read_labels: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can read the labels on the file.", alias="canReadLabels")
    can_read_revisions: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can read the revisions resource of this file. For a shared drive item, whether revisions of non-folder descendants of this item, or this item itself if it is not a folder, can be read.", alias="canReadRevisions")
    can_read_team_drive: Optional[StrictBool] = Field(default=None, description="Deprecated: Output only. Use `canReadDrive` instead.", alias="canReadTeamDrive")
    can_remove_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can remove children from this folder. This is always false when the item is not a folder. For a folder in a shared drive, use `canDeleteChildren` or `canTrashChildren` instead.", alias="canRemoveChildren")
    can_remove_content_restriction: Optional[StrictBool] = Field(default=None, description="Output only. Whether there is a content restriction on the file that can be removed by the current user.", alias="canRemoveContentRestriction")
    can_remove_my_drive_parent: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can remove a parent from the item without adding another parent in the same request. Not populated for shared drive files.", alias="canRemoveMyDriveParent")
    can_rename: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can rename this file.", alias="canRename")
    can_share: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can modify the sharing settings for this file.", alias="canShare")
    can_trash: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can move this file to trash.", alias="canTrash")
    can_trash_children: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can trash children of this folder. This is false when the item is not a folder. Only populated for items in shared drives.", alias="canTrashChildren")
    can_untrash: Optional[StrictBool] = Field(default=None, description="Output only. Whether the current user can restore this file from trash.", alias="canUntrash")
    __properties: ClassVar[List[str]] = ["canAcceptOwnership", "canAddChildren", "canAddFolderFromAnotherDrive", "canAddMyDriveParent", "canChangeCopyRequiresWriterPermission", "canChangeSecurityUpdateEnabled", "canChangeViewersCanCopyContent", "canComment", "canCopy", "canDelete", "canDeleteChildren", "canDownload", "canEdit", "canListChildren", "canModifyContent", "canModifyContentRestriction", "canModifyEditorContentRestriction", "canModifyLabels", "canModifyOwnerContentRestriction", "canMoveChildrenOutOfDrive", "canMoveChildrenOutOfTeamDrive", "canMoveChildrenWithinDrive", "canMoveChildrenWithinTeamDrive", "canMoveItemIntoTeamDrive", "canMoveItemOutOfDrive", "canMoveItemOutOfTeamDrive", "canMoveItemWithinDrive", "canMoveItemWithinTeamDrive", "canMoveTeamDriveItem", "canReadDrive", "canReadLabels", "canReadRevisions", "canReadTeamDrive", "canRemoveChildren", "canRemoveContentRestriction", "canRemoveMyDriveParent", "canRename", "canShare", "canTrash", "canTrashChildren", "canUntrash"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FileCapabilities from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FileCapabilities from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "canAcceptOwnership": obj.get("canAcceptOwnership"),
            "canAddChildren": obj.get("canAddChildren"),
            "canAddFolderFromAnotherDrive": obj.get("canAddFolderFromAnotherDrive"),
            "canAddMyDriveParent": obj.get("canAddMyDriveParent"),
            "canChangeCopyRequiresWriterPermission": obj.get("canChangeCopyRequiresWriterPermission"),
            "canChangeSecurityUpdateEnabled": obj.get("canChangeSecurityUpdateEnabled"),
            "canChangeViewersCanCopyContent": obj.get("canChangeViewersCanCopyContent"),
            "canComment": obj.get("canComment"),
            "canCopy": obj.get("canCopy"),
            "canDelete": obj.get("canDelete"),
            "canDeleteChildren": obj.get("canDeleteChildren"),
            "canDownload": obj.get("canDownload"),
            "canEdit": obj.get("canEdit"),
            "canListChildren": obj.get("canListChildren"),
            "canModifyContent": obj.get("canModifyContent"),
            "canModifyContentRestriction": obj.get("canModifyContentRestriction"),
            "canModifyEditorContentRestriction": obj.get("canModifyEditorContentRestriction"),
            "canModifyLabels": obj.get("canModifyLabels"),
            "canModifyOwnerContentRestriction": obj.get("canModifyOwnerContentRestriction"),
            "canMoveChildrenOutOfDrive": obj.get("canMoveChildrenOutOfDrive"),
            "canMoveChildrenOutOfTeamDrive": obj.get("canMoveChildrenOutOfTeamDrive"),
            "canMoveChildrenWithinDrive": obj.get("canMoveChildrenWithinDrive"),
            "canMoveChildrenWithinTeamDrive": obj.get("canMoveChildrenWithinTeamDrive"),
            "canMoveItemIntoTeamDrive": obj.get("canMoveItemIntoTeamDrive"),
            "canMoveItemOutOfDrive": obj.get("canMoveItemOutOfDrive"),
            "canMoveItemOutOfTeamDrive": obj.get("canMoveItemOutOfTeamDrive"),
            "canMoveItemWithinDrive": obj.get("canMoveItemWithinDrive"),
            "canMoveItemWithinTeamDrive": obj.get("canMoveItemWithinTeamDrive"),
            "canMoveTeamDriveItem": obj.get("canMoveTeamDriveItem"),
            "canReadDrive": obj.get("canReadDrive"),
            "canReadLabels": obj.get("canReadLabels"),
            "canReadRevisions": obj.get("canReadRevisions"),
            "canReadTeamDrive": obj.get("canReadTeamDrive"),
            "canRemoveChildren": obj.get("canRemoveChildren"),
            "canRemoveContentRestriction": obj.get("canRemoveContentRestriction"),
            "canRemoveMyDriveParent": obj.get("canRemoveMyDriveParent"),
            "canRename": obj.get("canRename"),
            "canShare": obj.get("canShare"),
            "canTrash": obj.get("canTrash"),
            "canTrashChildren": obj.get("canTrashChildren"),
            "canUntrash": obj.get("canUntrash")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.generated_ids import GeneratedIds

class TestGeneratedIds(unittest.TestCase):
    """GeneratedIds unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeneratedIds:
        """Test GeneratedIds
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeneratedIds`
        """
        model = GeneratedIds()
        if include_optional:
            return GeneratedIds(
                ids = [
                    ''
                    ],
                kind = 'drive#generatedIds',
                space = ''
            )
        else:
            return GeneratedIds(
        )
        """

    def testGeneratedIds(self):
        """Test GeneratedIds"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ResolveAccessProposalRequest(BaseModel):
    """
    Request message for resolving an AccessProposal on a file.
    """ # noqa: E501
    action: Optional[StrictStr] = Field(default=None, description="Required. The action to take on the AccessProposal.")
    role: Optional[List[StrictStr]] = Field(default=None, description="Optional. The roles the approver has allowed, if any. Note: This field is required for the `ACCEPT` action.")
    send_notification: Optional[StrictBool] = Field(default=None, description="Optional. Whether to send an email to the requester when the AccessProposal is denied or accepted.", alias="sendNotification")
    view: Optional[StrictStr] = Field(default=None, description="Optional. Indicates the view for this access proposal. This should only be set when the proposal belongs to a view. `published` is the only supported value.")
    __properties: ClassVar[List[str]] = ["action", "role", "sendNotification", "view"]

    @field_validator('action')
    def action_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ACTION_UNSPECIFIED', 'ACCEPT', 'DENY']):
            raise ValueError("must be one of enum values ('ACTION_UNSPECIFIED', 'ACCEPT', 'DENY')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ResolveAccessProposalRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ResolveAccessProposalRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "action": obj.get("action"),
            "role": obj.get("role"),
            "sendNotification": obj.get("sendNotification"),
            "view": obj.get("view")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.drive_list import DriveList

class TestDriveList(unittest.TestCase):
    """DriveList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DriveList:
        """Test DriveList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DriveList`
        """
        model = DriveList()
        if include_optional:
            return DriveList(
                drives = [
                    google_drive_ti.models.drive.Drive(
                        background_image_file = google_drive_ti.models.drive_background_image_file.Drive_backgroundImageFile(
                            id = '', 
                            width = 1.337, 
                            x_coordinate = 1.337, 
                            y_coordinate = 1.337, ), 
                        background_image_link = '', 
                        capabilities = google_drive_ti.models.drive_capabilities.Drive_capabilities(
                            can_add_children = True, 
                            can_change_copy_requires_writer_permission_restriction = True, 
                            can_change_domain_users_only_restriction = True, 
                            can_change_drive_background = True, 
                            can_change_drive_members_only_restriction = True, 
                            can_change_sharing_folders_requires_organizer_permission_restriction = True, 
                            can_comment = True, 
                            can_copy = True, 
                            can_delete_children = True, 
                            can_delete_drive = True, 
                            can_download = True, 
                            can_edit = True, 
                            can_list_children = True, 
                            can_manage_members = True, 
                            can_read_revisions = True, 
                            can_rename = True, 
                            can_rename_drive = True, 
                            can_reset_drive_restrictions = True, 
                            can_share = True, 
                            can_trash_children = True, ), 
                        color_rgb = '', 
                        created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        hidden = True, 
                        id = '', 
                        kind = 'drive#drive', 
                        name = '', 
                        org_unit_id = '', 
                        restrictions = google_drive_ti.models.drive_restrictions.Drive_restrictions(
                            admin_managed_restrictions = True, 
                            copy_requires_writer_permission = True, 
                            domain_users_only = True, 
                            drive_members_only = True, 
                            sharing_folders_requires_organizer_permission = True, ), 
                        theme_id = '', )
                    ],
                kind = 'drive#driveList',
                next_page_token = ''
            )
        else:
            return DriveList(
        )
        """

    def testDriveList(self):
        """Test DriveList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.access_proposal import AccessProposal

class TestAccessProposal(unittest.TestCase):
    """AccessProposal unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessProposal:
        """Test AccessProposal
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccessProposal`
        """
        model = AccessProposal()
        if include_optional:
            return AccessProposal(
                create_time = '',
                file_id = '',
                proposal_id = '',
                recipient_email_address = '',
                request_message = '',
                requester_email_address = '',
                roles_and_views = [
                    google_drive_ti.models.access_proposal_role_and_view.AccessProposalRoleAndView(
                        role = '', 
                        view = '', )
                    ]
            )
        else:
            return AccessProposal(
        )
        """

    def testAccessProposal(self):
        """Test AccessProposal"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.file_capabilities import FileCapabilities

class TestFileCapabilities(unittest.TestCase):
    """FileCapabilities unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileCapabilities:
        """Test FileCapabilities
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileCapabilities`
        """
        model = FileCapabilities()
        if include_optional:
            return FileCapabilities(
                can_accept_ownership = True,
                can_add_children = True,
                can_add_folder_from_another_drive = True,
                can_add_my_drive_parent = True,
                can_change_copy_requires_writer_permission = True,
                can_change_security_update_enabled = True,
                can_change_viewers_can_copy_content = True,
                can_comment = True,
                can_copy = True,
                can_delete = True,
                can_delete_children = True,
                can_download = True,
                can_edit = True,
                can_list_children = True,
                can_modify_content = True,
                can_modify_content_restriction = True,
                can_modify_editor_content_restriction = True,
                can_modify_labels = True,
                can_modify_owner_content_restriction = True,
                can_move_children_out_of_drive = True,
                can_move_children_out_of_team_drive = True,
                can_move_children_within_drive = True,
                can_move_children_within_team_drive = True,
                can_move_item_into_team_drive = True,
                can_move_item_out_of_drive = True,
                can_move_item_out_of_team_drive = True,
                can_move_item_within_drive = True,
                can_move_item_within_team_drive = True,
                can_move_team_drive_item = True,
                can_read_drive = True,
                can_read_labels = True,
                can_read_revisions = True,
                can_read_team_drive = True,
                can_remove_children = True,
                can_remove_content_restriction = True,
                can_remove_my_drive_parent = True,
                can_rename = True,
                can_share = True,
                can_trash = True,
                can_trash_children = True,
                can_untrash = True
            )
        else:
            return FileCapabilities(
        )
        """

    def testFileCapabilities(self):
        """Test FileCapabilities"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.drive_capabilities import DriveCapabilities

class TestDriveCapabilities(unittest.TestCase):
    """DriveCapabilities unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DriveCapabilities:
        """Test DriveCapabilities
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DriveCapabilities`
        """
        model = DriveCapabilities()
        if include_optional:
            return DriveCapabilities(
                can_add_children = True,
                can_change_copy_requires_writer_permission_restriction = True,
                can_change_domain_users_only_restriction = True,
                can_change_drive_background = True,
                can_change_drive_members_only_restriction = True,
                can_change_sharing_folders_requires_organizer_permission_restriction = True,
                can_comment = True,
                can_copy = True,
                can_delete_children = True,
                can_delete_drive = True,
                can_download = True,
                can_edit = True,
                can_list_children = True,
                can_manage_members = True,
                can_read_revisions = True,
                can_rename = True,
                can_rename_drive = True,
                can_reset_drive_restrictions = True,
                can_share = True,
                can_trash_children = True
            )
        else:
            return DriveCapabilities(
        )
        """

    def testDriveCapabilities(self):
        """Test DriveCapabilities"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.about_drive_themes_inner import AboutDriveThemesInner
from google_drive_ti.models.about_storage_quota import AboutStorageQuota
from google_drive_ti.models.about_team_drive_themes_inner import AboutTeamDriveThemesInner
from google_drive_ti.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class About(BaseModel):
    """
    Information about the user, the user's Drive, and system capabilities.
    """ # noqa: E501
    app_installed: Optional[StrictBool] = Field(default=None, description="Whether the user has installed the requesting app.", alias="appInstalled")
    can_create_drives: Optional[StrictBool] = Field(default=None, description="Whether the user can create shared drives.", alias="canCreateDrives")
    can_create_team_drives: Optional[StrictBool] = Field(default=None, description="Deprecated: Use `canCreateDrives` instead.", alias="canCreateTeamDrives")
    drive_themes: Optional[List[AboutDriveThemesInner]] = Field(default=None, description="A list of themes that are supported for shared drives.", alias="driveThemes")
    export_formats: Optional[Dict[str, Any]] = Field(default=None, description="A map of source MIME type to possible targets for all supported exports.", alias="exportFormats")
    folder_color_palette: Optional[List[StrictStr]] = Field(default=None, description="The currently supported folder colors as RGB hex strings.", alias="folderColorPalette")
    import_formats: Optional[Dict[str, Any]] = Field(default=None, description="A map of source MIME type to possible targets for all supported imports.", alias="importFormats")
    kind: Optional[StrictStr] = Field(default='drive#about', description="Identifies what kind of resource this is. Value: the fixed string `\"drive#about\"`.")
    max_import_sizes: Optional[Dict[str, Any]] = Field(default=None, description="A map of maximum import sizes by MIME type, in bytes.", alias="maxImportSizes")
    max_upload_size: Optional[StrictStr] = Field(default=None, description="The maximum upload size in bytes.", alias="maxUploadSize")
    storage_quota: Optional[AboutStorageQuota] = Field(default=None, alias="storageQuota")
    team_drive_themes: Optional[List[AboutTeamDriveThemesInner]] = Field(default=None, description="Deprecated: Use `driveThemes` instead.", alias="teamDriveThemes")
    user: Optional[User] = None
    __properties: ClassVar[List[str]] = ["appInstalled", "canCreateDrives", "canCreateTeamDrives", "driveThemes", "exportFormats", "folderColorPalette", "importFormats", "kind", "maxImportSizes", "maxUploadSize", "storageQuota", "teamDriveThemes", "user"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of About from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in drive_themes (list)
        _items = []
        if self.drive_themes:
            for _item_drive_themes in self.drive_themes:
                if _item_drive_themes:
                    _items.append(_item_drive_themes.to_dict())
            _dict['driveThemes'] = _items
        # override the default output from pydantic by calling `to_dict()` of storage_quota
        if self.storage_quota:
            _dict['storageQuota'] = self.storage_quota.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in team_drive_themes (list)
        _items = []
        if self.team_drive_themes:
            for _item_team_drive_themes in self.team_drive_themes:
                if _item_team_drive_themes:
                    _items.append(_item_team_drive_themes.to_dict())
            _dict['teamDriveThemes'] = _items
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of About from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "appInstalled": obj.get("appInstalled"),
            "canCreateDrives": obj.get("canCreateDrives"),
            "canCreateTeamDrives": obj.get("canCreateTeamDrives"),
            "driveThemes": [AboutDriveThemesInner.from_dict(_item) for _item in obj["driveThemes"]] if obj.get("driveThemes") is not None else None,
            "exportFormats": obj.get("exportFormats"),
            "folderColorPalette": obj.get("folderColorPalette"),
            "importFormats": obj.get("importFormats"),
            "kind": obj.get("kind") if obj.get("kind") is not None else 'drive#about',
            "maxImportSizes": obj.get("maxImportSizes"),
            "maxUploadSize": obj.get("maxUploadSize"),
            "storageQuota": AboutStorageQuota.from_dict(obj["storageQuota"]) if obj.get("storageQuota") is not None else None,
            "teamDriveThemes": [AboutTeamDriveThemesInner.from_dict(_item) for _item in obj["teamDriveThemes"]] if obj.get("teamDriveThemes") is not None else None,
            "user": User.from_dict(obj["user"]) if obj.get("user") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class DriveBackgroundImageFile(BaseModel):
    """
    An image file and cropping parameters from which a background image for this shared drive is set. This is a write only field; it can only be set on `drive.drives.update` requests that don't set `themeId`. When specified, all fields of the `backgroundImageFile` must be set.
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The ID of an image file in Google Drive to use for the background image.")
    width: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The width of the cropped image in the closed range of 0 to 1. This value represents the width of the cropped image divided by the width of the entire image. The height is computed by applying a width to height aspect ratio of 80 to 9. The resulting image must be at least 1280 pixels wide and 144 pixels high.")
    x_coordinate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The X coordinate of the upper left corner of the cropping area in the background image. This is a value in the closed range of 0 to 1. This value represents the horizontal distance from the left side of the entire image to the left side of the cropping area divided by the width of the entire image.", alias="xCoordinate")
    y_coordinate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The Y coordinate of the upper left corner of the cropping area in the background image. This is a value in the closed range of 0 to 1. This value represents the vertical distance from the top side of the entire image to the top side of the cropping area divided by the height of the entire image.", alias="yCoordinate")
    __properties: ClassVar[List[str]] = ["id", "width", "xCoordinate", "yCoordinate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DriveBackgroundImageFile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DriveBackgroundImageFile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "width": obj.get("width"),
            "xCoordinate": obj.get("xCoordinate"),
            "yCoordinate": obj.get("yCoordinate")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.status import Status
from typing import Optional, Set
from typing_extensions import Self

class Operation(BaseModel):
    """
    This resource represents a long-running operation that is the result of a network API call.
    """ # noqa: E501
    done: Optional[StrictBool] = Field(default=None, description="If the value is `false`, it means the operation is still in progress. If `true`, the operation is completed, and either `error` or `response` is available.")
    error: Optional[Status] = None
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any.")
    name: Optional[StrictStr] = Field(default=None, description="The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the `name` should be a resource name ending with `operations/{unique_id}`.")
    response: Optional[Dict[str, Any]] = Field(default=None, description="The normal, successful response of the operation. If the original method returns no data on success, such as `Delete`, the response is `google.protobuf.Empty`. If the original method is standard `Get`/`Create`/`Update`, the response should be the resource. For other methods, the response should have the type `XxxResponse`, where `Xxx` is the original method name. For example, if the original method name is `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.")
    __properties: ClassVar[List[str]] = ["done", "error", "metadata", "name", "response"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Operation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of error
        if self.error:
            _dict['error'] = self.error.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Operation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "done": obj.get("done"),
            "error": Status.from_dict(obj["error"]) if obj.get("error") is not None else None,
            "metadata": obj.get("metadata"),
            "name": obj.get("name"),
            "response": obj.get("response")
        })
        return _obj





# flake8: noqa

# import apis into api package
from google_drive_ti.api.about_api import AboutApi
from google_drive_ti.api.accessproposals_api import AccessproposalsApi
from google_drive_ti.api.apps_api import AppsApi
from google_drive_ti.api.changes_api import ChangesApi
from google_drive_ti.api.channels_api import ChannelsApi
from google_drive_ti.api.comments_api import CommentsApi
from google_drive_ti.api.drives_api import DrivesApi
from google_drive_ti.api.files_api import FilesApi
from google_drive_ti.api.operation_api import OperationApi
from google_drive_ti.api.operations_api import OperationsApi
from google_drive_ti.api.permissions_api import PermissionsApi
from google_drive_ti.api.replies_api import RepliesApi
from google_drive_ti.api.revisions_api import RevisionsApi
from google_drive_ti.api.teamdrives_api import TeamdrivesApi

